<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

include_once("auth.php");
db_connect($db_host, $db_user, $db_pass);

$indexcode = str_replace(chr(174), '&reg;', $indexcode);
$indexcode = str_replace(chr(169), '&copy;', $indexcode);
$indexcode = addslashes($indexcode);
$indexfile = addslashes($indexfile);

db_query("update admin set indexcode = '$indexcode', indexfile = '$indexfile' WHERE server_id='$ServerID'");
db_query("update anbieter set indexcode = '$indexcode', indexfile = '$indexfile' where anbieter='res0' AND server_id='$ServerID'");

$fehlertitel = ltext("anin2_errortitle");
$fehlertext = ltext("anin2_error1");
db_close();
include("anbieter_index.php");
exit();
?>
